---
title: pyprofibus stub libs
---

This directory contains stubs, wrappers and minimal implementations of
libraries used by pyprofibus.

The purpose of these libraries is to support pyprofibus execution on
restricted Python interpreters such as Micropython.
